/*

Copyright 2011 Giuseppe Cosentino Borgese <gicos.2@gmail.com>

This file is part of gSudoku.

gSudoku is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

gSudoku is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with gSudoku.  If not, see
<http://www.gnu.org/licenses/>.

*/

#include "curses.h"
#include "Frontend/GUIMain.h"
#include "Frontend/GUIInfo.h"
#include "Frontend/GUISudoku.h"
#include "Frontend/GUIError.h"
#include "Backend/SudokuDB.h"

void printLogo(WINDOW *mainWin, int xLogo){
	clear();
	mvwaddstr(mainWin, 1, xLogo, "   _____             __        __         ");
	mvwaddstr(mainWin, 2, xLogo, "  / ___/ __  __ ____/ /____   / /__ __  __");
	mvwaddstr(mainWin, 3, xLogo, "  \\__ \\ / / / // __  // __ \\ / //_// / / /");
	mvwaddstr(mainWin, 4, xLogo, " ___/ // /_/ // /_/ // /_/ // ,<  / /_/ / ");
	mvwaddstr(mainWin, 5, xLogo, "/____/ \\__,_/ \\__,_/ \\____//_/|_| \\__,_/");
}

int main() {
	WINDOW *mainWin;
	mainWin = initscr();
	curs_set(0);
	keypad(mainWin, TRUE);
	raw();
	noecho();
	start_color();

	init_pair(1, COLOR_WHITE, COLOR_BLACK); // Testo normale
	init_pair(2, COLOR_BLACK, COLOR_WHITE); // Testo evidenziato
	init_pair(3, COLOR_YELLOW, COLOR_BLACK); // Celle fissate (Sudoku)
	init_pair(4, COLOR_GREEN, COLOR_BLACK); // Celle corrette (Sudoku)
	init_pair(5, COLOR_WHITE, COLOR_RED); // Celle errate (Sudoku)
	init_pair(6, COLOR_BLACK, COLOR_YELLOW); // Testo evidenziato 2
	init_pair(7, COLOR_WHITE, COLOR_BLUE); // Testo evidenziato - Cella normale
	init_pair(8, COLOR_WHITE, COLOR_YELLOW); // Testo evidenziato  - Cella fissa
	init_pair(9, COLOR_WHITE, COLOR_GREEN); // Testo evidenziato  - Cella corretta

	int uOpt;
	int maxX, maxY;
	do{
		getmaxyx(mainWin, maxY, maxX);
		if(maxX < 80 || maxY < 24){
			GUIError e(mainWin, 2, 1, true);
			e.showError("Terminale non 80x24");
		}
	}while(maxX < 80 || maxY < 24);

	do{
		printLogo(mainWin, (maxX - 44) / 2);
		GUIMain m(mainWin, maxY, maxX);
		uOpt = m.mainMenu();

		if(uOpt / 10 == 1){
			GUISudoku s(mainWin, maxY, maxX, uOpt % 10);
			s.playSudoku();
		}else if(uOpt == 80){
			printLogo(mainWin, (maxX - 44) / 2);
			GUIInfo i(mainWin, maxY, maxX);
			i.showInfo();
		}
	}while(uOpt != 90);

	delwin(mainWin);
	endwin();
	refresh();

	return 0;
}
